==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteMatchHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property invert If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
 * @property match Method and value to match the header value sent with a request. Specify one match method.
 * @property name Name for the HTTP header in the client request that will be matched on.
 */
public data class GatewayRouteSpecHttpRouteMatchHeaderArgs(
    public val invert: Output<Boolean>? = null,
    public val match: Output<GatewayRouteSpecHttpRouteMatchHeaderMatchArgs>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs.builder()
            .invert(invert?.applyValue({ args0 -> args0 }))
            .match(match?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteMatchHeaderArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteMatchHeaderArgsBuilder internal constructor() {
    private var invert: Output<Boolean>? = null

    private var match: Output<GatewayRouteSpecHttpRouteMatchHeaderMatchArgs>? = null

    private var name: Output<String>? = null

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("abyebnmaxketakdj")
    public suspend fun invert(`value`: Output<Boolean>) {
        this.invert = value
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("nlydjwsfivudlxip")
    public suspend fun match(`value`: Output<GatewayRouteSpecHttpRouteMatchHeaderMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("dgrghkcctgakwtte")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("wemuqtauxrfhphvt")
    public suspend fun invert(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.invert = mapped
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("ijwacgflnfljrorn")
    public suspend fun match(`value`: GatewayRouteSpecHttpRouteMatchHeaderMatchArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("emkbrblahikttjup")
    public suspend
    fun match(argument: suspend GatewayRouteSpecHttpRouteMatchHeaderMatchArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttpRouteMatchHeaderMatchArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("nktvuqjbccmhsnew")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteMatchHeaderArgs =
        GatewayRouteSpecHttpRouteMatchHeaderArgs(
            invert = invert,
            match = match,
            name = name ?: throw PulumiNullFieldException("name"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteMatchHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property invert If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
 * @property match Method and value to match the header value sent with a request. Specify one match method.
 * @property name Name for the HTTP header in the client request that will be matched on.
 */
public data class GatewayRouteSpecHttpRouteMatchHeaderArgs(
    public val invert: Output<Boolean>? = null,
    public val match: Output<GatewayRouteSpecHttpRouteMatchHeaderMatchArgs>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteMatchHeaderArgs.builder()
            .invert(invert?.applyValue({ args0 -> args0 }))
            .match(match?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteMatchHeaderArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteMatchHeaderArgsBuilder internal constructor() {
    private var invert: Output<Boolean>? = null

    private var match: Output<GatewayRouteSpecHttpRouteMatchHeaderMatchArgs>? = null

    private var name: Output<String>? = null

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("lcrieekjdnrpgasn")
    public suspend fun invert(`value`: Output<Boolean>) {
        this.invert = value
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("flndtdmurkwmdmmd")
    public suspend fun match(`value`: Output<GatewayRouteSpecHttpRouteMatchHeaderMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("qwddnvatxkvmhjun")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value If `true`, the match is on the opposite of the `match` method and value. Default is `false`.
     */
    @JvmName("rphnycllpvuwomnm")
    public suspend fun invert(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.invert = mapped
    }

    /**
     * @param value Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("vmomqjchvdklflph")
    public suspend fun match(`value`: GatewayRouteSpecHttpRouteMatchHeaderMatchArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Method and value to match the header value sent with a request. Specify one match method.
     */
    @JvmName("scbpqgspvrgejkbn")
    public suspend fun match(argument: suspend GatewayRouteSpecHttpRouteMatchHeaderMatchArgsBuilder.() -> Unit) {
        val toBeMapped = GatewayRouteSpecHttpRouteMatchHeaderMatchArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    /**
     * @param value Name for the HTTP header in the client request that will be matched on.
     */
    @JvmName("xnjohfuodotekkvo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteMatchHeaderArgs =
        GatewayRouteSpecHttpRouteMatchHeaderArgs(
            invert = invert,
            match = match,
            name = name ?: throw PulumiNullFieldException("name"),
        )
}
